import { Range } from "./interfaces";
/**
 * Validates the range.
 * @throws {RangeError} If the min is out of range, the max is out of range,
 * or the min is greater than the max.
 * @param {Partial<Range>} range The range to validate.
 * @param {Partial<Range>} bounds Upper and lower inclusive bounds for the range.
 * @returns {Range} The validated range.
 * @example
 * // returns { min: -5, max: 5 }
 * // validateRange({ max: 5 }, { min: -5, max: 25 })
 * @example
 * // throws RangeError since range is out of bounds
 * // validateRange({ min: -5, max: 5 }, { min: 0, max: 5 })
 */
export declare const validateRange: (range?: Partial<Range>, bounds?: Partial<Range>) => Range;
